@@ -1,5 +1,5 @@
+// $Id: Graph.cc,v 1.1 2000/08/30 22:55:49 dave Exp $
 /*  Graph  Abstract superclass for all graphs.
-    Last modified 1999-08-14
 
     Copyright (C) 1998  David Flater.
 
@@ -138,9 +138,11 @@ Settings *settings, int x, Colors::colorchoice c) {
 
 void Graph::clearGraph (Timestamp start, Timestamp endt, Interval increment,
 Station *sr, struct Graph::tideline *first) {
+  assert (sr);
+  Settings *settings = sr->context->settings;
   // Clear the graph by laying down a background of days and nights.
   int sunisup = 1;
-  if (!(sr->coordinates.isNull()))
+  if (!(sr->coordinates.isNull()) && settings->ns == "n")
     sunisup = sun_is_up (start, sr->coordinates);
   int x;
   struct tideline *t;
