@@ -1,4 +1,4 @@
-// 	$Id: HarmonicsFile.cc,v 1.2 1999/12/05 19:45:42 dave Exp $	
+// 	$Id: HarmonicsFile.cc,v 1.4 2001/03/23 21:51:08 dave Exp $	
 /*  HarmonicsFile  Operations for reading harmonics files.
 
     Copyright (C) 1998  David Flater.
@@ -79,6 +79,30 @@ void HarmonicsFile::getline_f (Dstr &inbuf) {
   }
 }
 
+void HarmonicsFile::get_version_string (FILE *fp) {
+  Dstr inbuf;
+  inbuf.getline (fp);
+  get_version_string (inbuf);
+  if (version_string.isNull()) {
+    inbuf.getline (fp);
+    get_version_string (inbuf);
+  }
+  rewind (fp);
+}
+
+void HarmonicsFile::get_version_string (Dstr &inbuf) {
+  int b = inbuf.strstr ("$Id");
+  if (b < 0)
+    return;
+  version_string = inbuf;
+  b++;
+  version_string /= (unsigned)b;
+  b = version_string.strrchr ('$');
+  if (b < 0)
+    return;
+  version_string -= (unsigned)b;
+}
+
 HarmonicsFile::HarmonicsFile (Dstr &filename, Settings *in_settings) {
   settings = in_settings;
   myxmlparsetree = NULL;
@@ -88,6 +112,7 @@ HarmonicsFile::HarmonicsFile (Dstr &filename, Settings *in_settings) {
   if (!fp) {
     xperror (myfilename->aschar());
   } else {
+    get_version_string (fp);
     Dstr inbuf;
     getline_f (inbuf);
     if (inbuf[0] == '<') {
@@ -99,7 +124,16 @@ HarmonicsFile::HarmonicsFile (Dstr &filename, Settings *in_settings) {
       xmlparsetree = NULL;
       xmlparse();
       fclose (xmlin);
-      myxmlparsetree = xmlparsetree;
+
+      if ((*(xmlparsetree->name)) == "document") {
+        // XTide 2.2.2: Dispose of root element if provided
+        myxmlparsetree = xmlparsetree->contents;
+        xmlparsetree->contents = NULL;
+        freexml (xmlparsetree);
+      } else {
+        // Old format offsets.xml
+        myxmlparsetree = xmlparsetree;
+      }
       xmlparsetree = NULL;
     } else {
       // Not an XML file.
@@ -260,6 +294,8 @@ HarmonicsFile::getNextStationRef () {
           sr->timezone = (*(a->value));
         else if ((*(a->name)) == "reference")
           sr->source = (*(a->value));
+        else if ((*(a->name)) == "note")
+          sr->note = (*(a->value));
         a = a->next;
       }
       // Do contents.  There should not be more than one offsets tag.
