@@ -1,5 +1,5 @@
+// $Id: Station.cc,v 1.1 2000/08/30 22:57:04 dave Exp $
 /*  Station  Abstract superclass of ReferenceStation and SubordinateStation.
-    Last modified 1999-07-20
 
     Copyright (C) 1998  David Flater.
 
@@ -389,6 +389,8 @@ Direction d)
 void Station::_predictExactTideEvent (Timestamp &tm, Direction d,
 EventType &etype_out) {
 
+  int ns = (context->settings->ns != 'n');
+
   // Workaround for failed initialization of TIDE_TIME_PREC on
   // AIX 4.2.1, IBM RS6000, 43P-140 (Alan J. Wylie)
   TIDE_TIME_PREC = Interval (def_TIDE_TIME_PREC);
@@ -402,15 +404,17 @@ EventType &etype_out) {
     t_sun.make_null();
   }
 
-  // Update sun
-  if (t_sun.isNull() && (!(coordinates.isNull()))) {
-    t_sun = tm;
-    find_next_sun_event (t_sun, coordinates, sun_t, d);
-  }
-  // Update moon
-  if (t_moon.isNull()) {
-    t_moon = tm;
-    find_next_moon_event (t_moon, moon_t, d);
+  if (!ns) {
+    // Update sun
+    if (t_sun.isNull() && (!(coordinates.isNull()))) {
+      t_sun = tm;
+      find_next_sun_event (t_sun, coordinates, sun_t, d);
+    }
+    // Update moon
+    if (t_moon.isNull()) {
+      t_moon = tm;
+      find_next_moon_event (t_moon, moon_t, d);
+    }
   }
 
   // If t_hilo is a valid cached value, then we needn't check again
@@ -464,51 +468,53 @@ EventType &etype_out) {
   }
 
   // Sun and moon -- let's try to keep this simple.  (Ha ha ha!)
-  Timestamp *t_sunmoon;
-  EventType sunmoon_t;
-  if (t_sun.isNull()) {
-    t_sunmoon = &t_moon;
-    sunmoon_t = moon_t;
-  } else {
-    if ((d == forward && t_moon < t_sun) ||
-        (d == backward && t_moon > t_sun)) {
+  if (!ns) {
+    Timestamp *t_sunmoon;
+    EventType sunmoon_t;
+    if (t_sun.isNull()) {
       t_sunmoon = &t_moon;
       sunmoon_t = moon_t;
     } else {
-      t_sunmoon = &t_sun;
-      sunmoon_t = sun_t;
-    }
-  }
-  // While we're waiting for goto to come back into style...
-  while (1) {
-    if (d == forward) {
-      if (!(t_hilo.isNull()))
-        if (t_hilo < *t_sunmoon)
-          break;
-      if (!(t_mark.isNull()))
-        if (t_mark < *t_sunmoon)
-          break;
-      if (!(t_slack.isNull()))
-        if (t_slack < *t_sunmoon)
-          break;
-    } else {
-      if (!(t_hilo.isNull()))
-        if (t_hilo > *t_sunmoon)
-          break;
-      if (!(t_mark.isNull()))
-        if (t_mark > *t_sunmoon)
-          break;
-      if (!(t_slack.isNull()))
-        if (t_slack > *t_sunmoon)
-          break;
+      if ((d == forward && t_moon < t_sun) ||
+	  (d == backward && t_moon > t_sun)) {
+	t_sunmoon = &t_moon;
+	sunmoon_t = moon_t;
+      } else {
+	t_sunmoon = &t_sun;
+	sunmoon_t = sun_t;
+      }
     }
+    // While we're waiting for goto to come back into style...
+    while (1) {
+      if (d == forward) {
+	if (!(t_hilo.isNull()))
+	  if (t_hilo < *t_sunmoon)
+	    break;
+	if (!(t_mark.isNull()))
+	  if (t_mark < *t_sunmoon)
+	    break;
+	if (!(t_slack.isNull()))
+	  if (t_slack < *t_sunmoon)
+	    break;
+      } else {
+	if (!(t_hilo.isNull()))
+	  if (t_hilo > *t_sunmoon)
+	    break;
+	if (!(t_mark.isNull()))
+	  if (t_mark > *t_sunmoon)
+	    break;
+	if (!(t_slack.isNull()))
+	  if (t_slack > *t_sunmoon)
+	    break;
+      }
 
-    // Sun/moon wins.
-    last_tm = tm = *t_sunmoon;
-    cache_d = d;
-    etype_out = sunmoon_t;
-    t_sunmoon->make_null(); // This is why I needed a pointer.
-    return;
+      // Sun/moon wins.
+      last_tm = tm = *t_sunmoon;
+      cache_d = d;
+      etype_out = sunmoon_t;
+      t_sunmoon->make_null(); // This is why I needed a pointer.
+      return;
+    }
   }
 
   // Okay, sun and moon are out of the picture.
