@@ -1,5 +1,5 @@
+// $Id: SubordinateStation.cc,v 1.1 2001/03/23 21:54:56 dave Exp $
 /*  SubordinateStation  Implementation for offset station.
-    Last modified 1998-12-13
 
     Copyright (C) 1998  David Flater.
 
@@ -25,6 +25,7 @@ SubordinateStationRef *ssr): Station (rs->context) {
   stationRef = ssr;
   name = ssr->name;
   timeZone = ssr->timezone;
+  note = ssr->note;
   if (timeZone.isNull())
     timeZone = rs->timeZone;
   coordinates = ssr->coordinates;
@@ -490,9 +491,9 @@ PredictionValue SubordinateStation::predictApproximate (Timestamp tm) {
     residualOffsets->max.levelAdd.Units (HI.Units());
   if (residualOffsets->min.levelAdd.Units() != HI.Units())
     residualOffsets->min.levelAdd.Units (HI.Units());
-  return HI * ((residualOffsets->max.levelMultiply() + 
+  return HI * ((residualOffsets->max.levelMultiply() +
                 residualOffsets->min.levelMultiply()) / 2.0 +
-               (residualOffsets->max.levelMultiply() - 
+               (residualOffsets->max.levelMultiply() -
                 residualOffsets->min.levelMultiply()) * magicnum)
              + (residualOffsets->max.levelAdd +
                 residualOffsets->min.levelAdd) / 2.0 +
