@@ -1,4 +1,4 @@
-// 	$Id: Timestamp.cc,v 1.3 1999/12/12 17:00:40 dave Exp $	
+// 	$Id: Timestamp.cc,v 1.8 2001/03/23 01:28:12 dave Exp $	
 // Timestamp:  encapsulation for all manner of time-related services needed
 // by XTide.
 
@@ -346,11 +346,6 @@ void Timestamp::print (Dstr &out_time, const Dstr &timezone, Settings *settings)
   assert (strftime (tempbuf, 79, fmt.aschar(), get_tm(timezone,settings)) < 79);
   tempbuf[79] = '\0';
   out_time = tempbuf;
-  // Kludge to get rid of leading zero on hours
-  int i;
-  if ((i = out_time.strstr (" 0")) != -1)
-    // FIXME -- Dstr[] should return a reference
-    *(out_time.ascharfrom(i+1)) = ' ';
 }
 
 void
@@ -359,8 +354,8 @@ Timestamp::printhour (Dstr &out_time, const Dstr &timezone, Settings *settings)
   assert (strftime (tempbuf, 79, settings->hf.aschar(), get_tm(timezone,settings)) < 79);
   tempbuf[79] = '\0';
   out_time = tempbuf;
-  // Kludge to get rid of leading zero on hours
-  if (out_time[0] == '0')
+  // Kludge to get rid of leading space on hours
+  if (out_time[0] == ' ')
     out_time /= 1;
 }
 
@@ -387,8 +382,8 @@ void Timestamp::printtime (Dstr &out_time, const Dstr &timezone, Settings *setti
   assert (strftime (tempbuf, 79, settings->tf.aschar(), get_tm(timezone,settings)) < 79);
   tempbuf[79] = '\0';
   out_time = tempbuf;
-  // Kludge to get rid of leading zero on hours
-  if (out_time[0] == '0')
+  // Kludge to get rid of leading space on hours
+  if (out_time[0] == ' ')
     out_time /= 1;
 }
 
@@ -406,11 +401,6 @@ void Timestamp::printdayheading (Dstr &out_heading, const Dstr &timezone,
   assert (strftime (tempbuf, 79, "%a %d", get_tm(timezone,settings)) < 79);
   tempbuf[79] = '\0';
   out_heading = tempbuf;
-  // Kludge to get rid of leading zero on hours
-  int i;
-  if ((i = out_heading.strstr (" 0")) != -1)
-    // FIXME -- Dstr[] should return a reference
-    *(out_heading.ascharfrom(i+1)) = ' ';
 }
 
 Timestamp::Timestamp (const Dstr &in_iso, const Dstr &timezone,
@@ -453,11 +443,28 @@ typedef enum {NEWZONEINFO=0, OLDZONEINFO=1, HP=2, BRAINDEAD=3, TZNULL=4}
 
 static tz_support tzlevel = TZNULL;
 
-/* The following are based on tzdata96i */
-// Added Antarctic stations from tzdata1999j 1999-12-12
+/* The following were originally based on tzdata96i.  Since then the
+   following churn has occurred:
 
-/* I note that tzdata96i is different yet again from even
-   NEWZONEINFO, which is whatever came with Slackware 3.1. */
+   1999-12-12
+   Added Antarctic stations from tzdata1999j
+     The Antarctic time zones had previously been guesswork.
+
+   2000-07-16
+   Added America/Iqaluit and America/Hermosillo from tzdata2000d
+     Sonora and Nunavut each made changes that forced new zones to
+     become necessary.
+
+   2000-08-30
+   Added America/Goose_Bay from tzdata2000f.
+
+   2000-10-01
+   Added :America/Belem, :America/Fortaleza, :America/Maceio from
+   tzdata2000d; revised abbreviation for Sao_Paulo.
+
+   It's unfortunate that these zones will be broken on platforms
+   having intermediate versions of the "new" zoneinfo.
+*/
 
 /* In many cases, these substitutions will either break DST adjustments
    or will be incorrect for historical dates.  It's not worth documenting
@@ -523,6 +530,7 @@ static char *subs[][4] = {
 {":America/Asuncion",           "AST4", "AST4", "AST4"},
 {":America/Atka",               ":US/Aleutian", "HAST10HADT",  "AST10ADT"},
 {":America/Barbados",           "AST4", "AST4", "AST4"},
+{":America/Belem",              ":Brazil/East", "BRT3", "BRT3"},
 {":America/Belize",             "CST6", "CST6", "CST6"},
 {":America/Bogota",             "EST5", "EST5", "EST5"},
 {":America/Buenos_Aires",       "ARST3", "ARST3", "AST3"},
@@ -538,7 +546,9 @@ static char *subs[][4] = {
 {":America/Edmonton",           ":Canada/Mountain", "MST7MDT", "MST7MDT"},
 {":America/El_Salvador",        "CST6", "CST6", "CST6"},
 {":America/Ensenada",           ":Mexico/BajaNorte", "PST8PDT", "PST8PDT"},
+{":America/Fortaleza",          ":Brazil/East", "BRT3", "BRT3"},
 {":America/Godthab",            "WGT3", "WGT3", "WGT3"},
+{":America/Goose_Bay",          ":Canada/Atlantic", "AST4ADT", "AST4ADT"},
 {":America/Grand_Turk",         ":US/Eastern", "EST5EDT", "EST5EDT"},
 {":America/Grenada",            "AST4", "AST4", "AST4"},
 {":America/Guadeloupe",         "AST4", "AST4", "AST4"},
@@ -547,10 +557,13 @@ static char *subs[][4] = {
 {":America/Guyana",             "EST3", "EST3", "EST3"},
 {":America/Halifax",            ":Canada/Atlantic", "AST4ADT", "AST4ADT"},
 {":America/Havana",             ":Cuba", "CST5", "CST5"},
+{":America/Hermosillo",         "MST7", "MST7", "MST7"},
+{":America/Iqaluit",            ":Canada/Central", "CST6CDT", "CST6CDT"},
 {":America/Jamaica",            ":Jamaica", "EST5EDT", "EST5EDT"},
 {":America/La_Paz",             "AST4", "AST4", "AST4"},
 {":America/Lima",               "EST5", "EST5", "EST5"},
 {":America/Los_Angeles",        ":US/Pacific", "PST8PDT", "PST8PDT"},
+{":America/Maceio",             ":Brazil/East", "BRT3", "BRT3"},
 {":America/Managua",            "CST6", "CST6", "CST6"},
 {":America/Manaus",             ":Brazil/West", "WST4", "WST4"},
 {":America/Martinique",         "AST4", "AST4", "AST4"},
@@ -572,7 +585,7 @@ static char *subs[][4] = {
 {":America/Regina",             ":Canada/Saskatchewan", "CST6", "CST6"},
 {":America/Santiago",           ":Chile/Continental", "CST4", "CST4"},
 {":America/Santo_Domingo",      "AST4", "AST4", "AST4"},
-{":America/Sao_Paulo",          ":Brazil/East", "EST3", "EST3"},
+{":America/Sao_Paulo",          ":Brazil/East", "BRT3", "BRT3"},
 {":America/Scoresbysund",       "EGT1", "EGT1", "EGT1"},
 {":America/St_Johns",      ":Canada/Newfoundland", "NST3:30NDT", "NST3:30NDT"},
 {":America/St_Kitts",           "AST4", "AST4", "AST4"},
