@@ -1,4 +1,4 @@
-// 	$Id: xttpd.cc,v 1.4 1999/12/05 20:18:27 dave Exp $	
+// 	$Id: xttpd.cc,v 1.10 2001/04/15 19:03:06 dave Exp $	
 /*  xttpd  XTide web server.
 
     Copyright (C) 1998  David Flater.
@@ -133,38 +133,38 @@ setup_socket (unsigned short port_number, int &s)
       webmaster /= 4;
     webmaster *= "webmaster@";
   }
-  webmaster *= "<A HREF=\"mailto:";
+  webmaster *= "<a href=\"mailto:";
   webmaster += "\">";
 }
 
 static void
 add_disclaimer (Dstr &foo) {
-  foo += "<CENTER><H2> NOT FOR NAVIGATION </H2></CENTER>\n\
-<BLOCKQUOTE>\n\
-<P>This program is distributed in the hope that it will be useful, but\n\
+  foo += "<center><h2> NOT FOR NAVIGATION </h2></center>\n\
+<blockquote>\n\
+<p>This program is distributed in the hope that it will be useful, but\n\
 WITHOUT ANY WARRANTY; without even the implied warranty of\n\
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  The author\n\
-assumes no liability for damages arising from use of these predictions.\n\
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.&nbsp; The author\n\
+assumes no liability for damages arising from use of these predictions.&nbsp;\n\
 They are not certified to be correct, and they\n\
 do not incorporate the effects of tropical storms, El Ni&ntilde;o,\n\
 seismic events, continental drift, or changes in global sea level.\n\
-</P></BLOCKQUOTE>\n";
+</p></blockquote>\n";
 }
 
 static void
 end_page (int s, int pure = 0) {
-  Dstr end_mess ("<HR>");
+  Dstr end_mess ("<hr>");
   if (pure)
-    end_mess += "<P><IMG SRC=\"/purec++.png\" ALIGN=LEFT HSPACE=25></P>";
-  end_mess += "<P> <A HREF=\"/\">Start over</A> <BR>\n";
-  end_mess += "<A HREF=\"/index.html\">Master index</A> <BR>\n";
-  end_mess += "<A HREF=\"/zones/\">Zone index</A> <BR>\n";
-  end_mess += "<A HREF=\"http://www.flaterco.com/xtide/\">XTide software</A> <BR>\n";
+    end_mess += "<p><img src=\"/purec++.png\" align=left hspace=25></p>";
+  end_mess += "<p> <a href=\"/\">Start over</a> <br>\n";
+  end_mess += "<a href=\"/index.html\">Master index</a> <br>\n";
+  end_mess += "<a href=\"/zones/\">Zone index</a> <br>\n";
+  end_mess += "<a href=\"http://www.flaterco.com/xtide/\">XTide software</a> <br>\n";
   end_mess += webmaster;
-  end_mess += "Feedback</A> <BR>\n";
-  end_mess += "<A HREF=\"/tricks.html\">Hints and tricks</A></P>\n\
-</BODY>\n\
-</HTML>\n";
+  end_mess += "Feedback</a> <br>\n";
+  end_mess += "<a href=\"/tricks.html\">Hints and tricks</a></p>\n\
+</body>\n\
+</html>\n";
   write (s, end_mess.aschar(), end_mess.length());
   close (s);
   exit (0);
@@ -177,10 +177,10 @@ HTTP/1.0 501 Not Implemented\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> HTTP Error </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><H1> HTTP Error </H1>\n\
-<P> So sorry!  This server cannot satisfy your request. </P>\n";
+<html>\n\
+<head><title> HTTP Error </title></head>\n\
+<body bgcolor=\"FFFFFF\"><h1> HTTP Error </h1>\n\
+<p>So sorry!&nbsp; This server cannot satisfy your request.</p>\n";
 
   write (s, barf_message, strlen (barf_message));
   end_page (s);
@@ -193,10 +193,10 @@ HTTP/1.0 404 Not Found\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> Not Found </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><H1> Not Found </H1>\n\
-<P> So sorry!  This server cannot satisfy your request. </P>\n";
+<html>\n\
+<head><title> Not Found </title></head>\n\
+<body bgcolor=\"FFFFFF\"><h1> Not Found </h1>\n\
+<p>So sorry!&nbsp; This server cannot satisfy your request.</p>\n";
 
   write (s, barf_message, strlen (barf_message));
   end_page (s);
@@ -209,10 +209,10 @@ HTTP/1.0 413 Request Entity Too Large\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> HTTP Error </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><H1> HTTP Error </H1>\n\
-<P> So sorry!  This server cannot satisfy your request. </P>\n";
+<html>\n\
+<head><title> HTTP Error </title></head>\n\
+<body bgcolor=\"FFFFFF\"><h1> HTTP Error </h1>\n\
+<p>So sorry!&nbsp; This server cannot satisfy your request.</p>\n";
 
   write (s, barf_message, strlen (barf_message));
   end_page (s);
@@ -225,40 +225,46 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> XTide Tide Prediction Server </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><CENTER><H1> XTide Tide Prediction Server </H1></CENTER>\n\
+<html>\n\
+<head><title> XTide Tide Prediction Server </title></head>\n\
+<body bgcolor=\"FFFFFF\"><center><h1> XTide Tide Prediction Server </h1></center>\n\
 \n\
-<CENTER>\n\
-<P>Copyright (C) 1998\n\
-David Flater.</P>\n\
-</CENTER>\n");
+<center>\n\
+<p>Copyright (C) 1998\n\
+David Flater.</p>\n\
+</center>\n");
   add_disclaimer (root_p);
-  root_p += "<BLOCKQUOTE>\n\
-<P>\n\
+  root_p += "<blockquote>\n\
+<p>\n\
 While this program is maintained by David Flater, the web site\n\
-itself is not.  Please direct feedback about problems with the web site to\n\
+itself is not.&nbsp; Please direct feedback about problems with the web site to\n\
 the local ";
   root_p += webmaster;
-  root_p += "webmaster</A>.</P></BLOCKQUOTE>\n\
-<P> XTide can provide tide predictions for thousands of places around the\n\
-world, but first you have to select a location.\n\
-There are three ways to do this.  One\n\
-way is just to enter its name here, and click on Search: </P>\n\
-<P><FORM METHOD=GET ACTION=\"/query\">\n\
-<INPUT NAME=\"location\" TYPE=text SIZE=\"48\">\n\
-<INPUT TYPE=submit VALUE=\"Search\"> <INPUT TYPE=reset VALUE=\"Clear\">\n\
-</FORM></P>\n\
+  root_p += "webmaster</a>.</p></blockquote>\n\
+<p> XTide can provide tide predictions for thousands of places around the\n\
+world, but first you have to select a location.&nbsp;\n\
+There are three ways to do this.&nbsp; One\n\
+way is just to enter its name here, and click on Search: </p>\n\
+<p><form method=get action=\"/query\">\n\
+<input name=\"location\" type=text size=\"48\">\n\
+<input type=submit value=\"Search\"> <input type=reset value=\"Clear\">\n\
+</form></p>\n\
 \n\
-<P> Your other choices are the <A HREF=\"/zones/\">zone index</A>, which\n\
+<p> Your other choices are the <a href=\"/zones/\">zone index</a>, which\n\
 indexes locations by time zone, and \n\
-the <A HREF=\"index.html\">master index</A>, which is just one big list\n\
-of every location supported by this server.  The master index could be\n\
-very large, so if you are on a slow connection, don't use it.</P>\n\
+the <a href=\"index.html\">master index</a>, which is just one big list\n\
+of every location supported by this server.&nbsp; The master index could be\n\
+very large, so if you are on a slow connection, don't use it.</p>\n\
 \n\
-<P> All images shipped by this web server are in PNG format.  Versions of\n\
+<p> All images shipped by this web server are in PNG format.&nbsp; Versions of\n\
 Netscape or Internet Explorer older than version 4 will not be able to\n\
-display them. </P>\n";
+display them. </p>\n";
+
+  if (!(context->stationIndex()->hfile_ids.isNull())) {
+    root_p += "<p>This server is using the following versions of the XTide data files:<br>";
+    root_p += context->stationIndex()->hfile_ids;
+    root_p += "</p>\n";
+  }
 
   write (s, root_p.aschar(), root_p.length());
   end_page (s);
@@ -276,21 +282,21 @@ list_location (Dstr &d, StationIndex *si, unsigned long i) {
   assert (si);
   StationRef *sr = (*si)[i];
   assert (sr);
-  d += "<TR><TD><A HREF=\"/locations/";
+  d += "<tr><td><a href=\"/locations/";
   d += i;
   d += ".html\">";
   d += sr->name;
-  d += "</A></TD><TD>";
+  d += "</a></td><td>";
   {
     Dstr fname;
     sr->shortHarmonicsFileName (fname);
     d += fname;
   }
-  d += "</TD><TD>";
+  d += "</td><td>";
   Dstr tempc;
   sr->coordinates.print (tempc);
   d += tempc;
-  d += "</TD></TR>\n";
+  d += "</td></tr>\n";
 }
 
 static void
@@ -305,11 +311,11 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> XTide Master Index </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><CENTER><H1> XTide Master Index </H1></CENTER>\n\
+<html>\n\
+<head><title> XTide Master Index </title></head>\n\
+<body bgcolor=\"FFFFFF\"><center><h1> XTide Master Index </h1></center>\n\
 \n\
-<P> Click on any location to get tide predictions. </P>\n");
+<p>Click on any location to get tide predictions.</p>\n");
   start_loclist (top_p);
   unsigned long i;
   StationIndex *si = context->stationIndex();
@@ -332,23 +338,23 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> XTide hints and tricks </TITLE></HEAD>\n\
-<BODY BGCOLOR=\"FFFFFF\"><CENTER><H1> XTide hints and tricks </H1></CENTER>\n\
+<html>\n\
+<head><title> XTide hints and tricks </title></head>\n\
+<body bgcolor=\"FFFFFF\"><center><h1> XTide hints and tricks </h1></center>\n\
 \n\
-<P> This web server uses numerically indexed URLs to load prediction\n\
-pages.  Those URLs look like this:</P>\n\
+<p> This web server uses numerically indexed URLs to load prediction\n\
+pages.&nbsp; Those URLs look like this:</p>\n\
 \n\
-<PRE>http://whatever/locations/nnn.html</PRE>\n\
+<pre>http://whatever/locations/nnn.html</pre>\n\
 \n\
-<P>For convenience, you can also load a prediction page with a\n\
-URL of the following form: </P>\n\
+<p>For convenience, you can also load a prediction page with a\n\
+URL of the following form: </p>\n\
 \n\
-<PRE>http://whatever/locations/name</PRE>\n\
+<pre>http://whatever/locations/name</pre>\n\
 \n\
-<P>You will receive an error if the name-based lookup gives ambiguous results,\n\
+<p>You will receive an error if the name-based lookup gives ambiguous results,\n\
 but these URLs have the advantage that they do not need to change every time\n\
-the tide data are updated.</P>");
+the tide data are updated.</p>");
 
   write (s, top_p.aschar(), top_p.length());
   end_page (s);
@@ -356,47 +362,47 @@ the tide data are updated.</P>");
 
 static void
 add_time_control (Dstr &text, Dstr &url, unsigned y, unsigned m, unsigned d) {
-  text += "<H2> Time Control </H2>\n";
-  text += "<P> <FORM METHOD=GET ACTION=\"";
+  text += "<h2> Time Control </h2>\n";
+  text += "<p> <form method=get action=\"";
   text += url;
-  text += "\">\nYear: <SELECT NAME=\"y\">\n";
+  text += "\">\nYear: <select name=\"y\">\n";
   unsigned i;
   for (i=globalfirstyear; i<=globallastyear; i++) {
     if (i == y)
-      text += "<OPTION selected>";
+      text += "<option selected>";
     else
-      text += "<OPTION>";
+      text += "<option>";
     text += i;
     text += "\n";
   }
-  text += "</SELECT>\n";
+  text += "</select>\n";
 
-  text += "Month: <SELECT NAME=\"m\">\n";
+  text += "Month: <select name=\"m\">\n";
   for (i=1; i<=12; i++) {
     if (i == m)
-      text += "<OPTION selected>";
+      text += "<option selected>";
     else
-      text += "<OPTION>";
+      text += "<option>";
     text += i;
     text += "\n";
   }
-  text += "</SELECT>\n";
+  text += "</select>\n";
 
-  text += "Day: <SELECT NAME=\"d\">\n";
+  text += "Day: <select name=\"d\">\n";
   for (i=1; i<=31; i++) {
     if (i == d)
-      text += "<OPTION selected>";
+      text += "<option selected>";
     else
-      text += "<OPTION>";
+      text += "<option>";
     text += i;
     text += "\n";
   }
-  text += "</SELECT>\n";
+  text += "</select>\n";
 
-  text += "<INPUT TYPE=submit VALUE=\"Go\"></FORM></P>";
-  text += "<P> Note:  predictions for some locations do not cover the\n\
-full span of years.  If your browser returns a blank page or a \"no data\"\n\
-error, then the predictions that you requested are not available. </P>\n";
+  text += "<input type=submit value=\"Go\"></form></p>";
+  text += "<p> Note:  predictions for some locations do not cover the\n\
+full span of years.&nbsp; If your browser returns a blank page or a \"no data\"\n\
+error, then the predictions that you requested are not available. </p>\n";
 }
 
 Timestamp
@@ -429,13 +435,13 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> ");
+<html>\n\
+<head><title> ");
 
   top_p += st->name;
-  top_p += "</TITLE></HEAD>\n<BODY BGCOLOR=\"FFFFFF\">\n<CENTER><H1> ";
+  top_p += "</title></head>\n<body bgcolor=\"FFFFFF\">\n<center><h1> ";
   top_p += st->name;
-  top_p += " <BR>\n";
+  top_p += " <br>\n";
 
   Dstr text_out, tc_out;
   Timestamp start_tm = parse_time_control (filename, st->timeZone,
@@ -455,43 +461,43 @@ Content-type: text/html\n\
   Dstr nowbuf;
   start_tm.print (nowbuf, st->timeZone, context->settings);
   top_p += nowbuf;
-  top_p += " </H1></CENTER>\n";
+  top_p += " </h1></center>\n";
 
   if (!zoneinfo_doesnt_suck) {
-    top_p += "<P> Warning:  this host machine is using an obsolete time zone\n\
-database.  Summer Time (Daylight Savings Time) adjustments will not be done\n\
-for some locations. </P>\n";
+    top_p += "<p> Warning:  this host machine is using an obsolete time zone\n\
+database.&nbsp; Summer Time (Daylight Savings Time) adjustments will not be done\n\
+for some locations. </p>\n";
   }
 
-  top_p += "<P><IMG SRC=\"/graphs/";
+  top_p += "<p><img src=\"/graphs/";
   top_p += i;
   top_p += ".png";
   top_p += tc_out;
-  top_p += "\" WIDTH=";
+  top_p += "\" width=";
   top_p += context->settings->gw;
-  top_p += " HEIGHT=";
+  top_p += " height=";
   top_p += context->settings->gh;
-  top_p += "></P><P><PRE>\n";
+  top_p += "></p><p><pre>\n";
 
   context->textMode (st, start_tm, text_out);
   top_p += text_out;
-  top_p += "</PRE></P>\n";
+  top_p += "</pre></p>\n";
 
   add_time_control (top_p, myurl, y, m, d);
 
-  top_p += "<H2> Tide Calendars </H2>\n";
-  top_p += "<P> <A HREF=\"/calendar/month/";
+  top_p += "<h2> Tide Calendars </h2>\n";
+  top_p += "<p> <a href=\"/calendar/month/";
   top_p += i;
   top_p += ".html";
   top_p += tc_out;
-  top_p += "\"> One month</A> <BR>\n";
-  top_p += "<A HREF=\"/calendar/year/";
+  top_p += "\"> One month</a> <br>\n";
+  top_p += "<a href=\"/calendar/year/";
   top_p += i;
   top_p += ".html";
   top_p += tc_out;
-  top_p += "\"> One year</A> </P>\n";
-  top_p += "<P> Calendars will be generated for the month/year noted\n\
-at the top of this page. </P>\n";
+  top_p += "\"> One year</a> </p>\n";
+  top_p += "<p> Calendars will be generated for the month/year noted\n\
+at the top of this page. </p>\n";
 
   add_disclaimer (top_p);
   write (s, top_p.aschar(), top_p.length());
@@ -521,18 +527,18 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> Exact Query Error </TITLE></HEAD>\n<BODY BGCOLOR=\"FFFFFF\">\n<CENTER>\n\
-<H1> Exact Query Error </H1></CENTER>\n");
+<html>\n\
+<head><title> Exact Query Error </title></head>\n<body bgcolor=\"FFFFFF\">\n<center>\n\
+<h1> Exact Query Error </h1></center>\n");
 
   switch(match)
   {
 	case -1:	// no match
-		top_p += "<P>No locations matched your query.</P>";
+		top_p += "<p>No locations matched your query.</p>";
 		break;
 
 	case -2:	// more than one match
-		top_p += "<P>More than one location matched your query.</P>\n";
+		top_p += "<p>More than one location matched your query.</p>\n";
 		break;
 
 	default:	// clear hit
@@ -601,10 +607,10 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> ");
+<html>\n\
+<head><title> ");
   top_p += st->name;
-  top_p += "</TITLE></HEAD>\n<BODY BGCOLOR=\"FFFFFF\">\n";
+  top_p += "</title></head>\n<body bgcolor=\"FFFFFF\">\n";
 
   Dstr tc_out;
   Timestamp start_tm = parse_time_control (filename, st->timeZone,
@@ -629,14 +635,14 @@ Content-type: text/html\n\
   }
 
   if (!zoneinfo_doesnt_suck) {
-    top_p += "<P> Warning:  this host machine is using an obsolete time zone\n\
-database.  Summer Time (Daylight Savings Time) adjustments will not be done\n\
-for some locations. </P>\n";
+    top_p += "<p> Warning:  this host machine is using an obsolete time zone\n\
+database.&nbsp; Summer Time (Daylight Savings Time) adjustments will not be done\n\
+for some locations. </p>\n";
   }
 
-  top_p += "<P>\n";
+  top_p += "<p>\n";
   Dstr text_out;
-  context->calendarMode (st, start_tm, end_tm, text_out, 1);
+  context->calendarMode (st, start_tm, end_tm, text_out, 1, 0);
   top_p += text_out;
   top_p += "</P>\n";
 
@@ -710,12 +716,12 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> ");
+<html>\n\
+<head><title> ");
   top_p += title;
-  top_p += "</TITLE></HEAD>\n<BODY BGCOLOR=\"FFFFFF\">\n<CENTER><H1> ";
+  top_p += "</title></head>\n<body bgcolor=\"FFFFFF\">\n<center><h1> ";
   top_p += title;
-  top_p += " </H1></CENTER>\n";
+  top_p += " </h1></center>\n";
 
   if (dn->subzones) {
     ZoneIndex::dnode *sn;
@@ -724,23 +730,23 @@ Content-type: text/html\n\
     else
       sn = dn;
     top_p += "\
-<P> Most zones consist of a region followed by a city name.  Choose the\n\
-zone that matches the country and time zone of the location that you want.\n\
+<p> Most zones consist of a region followed by a city name.&nbsp; Choose the\n\
+zone that matches the country and time zone of the location that you want.&nbsp;\n\
 For example:  places on the east coast of the U.S. are in zone\n\
 :America/New_York; places in New Brunswick, Canada are in zone\n\
-:America/Halifax.</P><UL>\n";
+:America/Halifax.</p><ul>\n";
     while (sn) {
-      top_p += "<LI><A HREF=\"/zones/";
+      top_p += "<li><a href=\"/zones/";
       top_p += sn->name;
       top_p += "\">";
       top_p += sn->name;
-      top_p += "</A></LI>\n";
+      top_p += "</a></li>\n";
       sn = sn->next;
     }
-    top_p += "</UL>\n";
+    top_p += "</ul>\n";
   }
   if (dn->il) {
-    top_p += "<P> Click on any location to get tide predictions. </P>\n";
+    top_p += "<p> Click on any location to get tide predictions. </p>\n";
     struct ZoneIndex::indexlist *ix = dn->il;
     unsigned long i = 0;
     start_loclist (top_p);
@@ -760,9 +766,9 @@ For example:  places on the east coast of the U.S. are in zone\n\
     Dstr upzone(filename);
     upzone -= upzone.length()-1;
     upzone -= upzone.strrchr('/')+1;
-    top_p += "<P> <A HREF=\"";
+    top_p += "<p> <a href=\"";
     top_p += upzone;
-    top_p += "\">Back up</A></P>\n";
+    top_p += "\">Back up</a></p>\n";
   }
   write (s, top_p.aschar(), top_p.length());
   end_page (s);
@@ -813,18 +819,18 @@ HTTP/1.0 200 OK\n\
 MIME-version: 1.0\n\
 Content-type: text/html\n\
 \n\
-<HTML>\n\
-<HEAD><TITLE> Query Results </TITLE></HEAD>\n<BODY BGCOLOR=\"FFFFFF\">\n<CENTER>\n\
-<H1> Query Results </H1></CENTER>\n");
+<html>\n\
+<head><title> Query Results </title></head>\n<body bgcolor=\"FFFFFF\">\n<center>\n\
+<h1> Query Results </h1></center>\n");
 
   unsigned long i, count = 0;
   StationIndex *si = context->stationIndex();
   for (i=0; i<si->length(); i++) {
     if ((*si)[i]->name %= locq) {
       if (count == 0) {
-        top_p += "<P>Locations matching \"";
+        top_p += "<p>Locations matching \"";
         top_p += locq;
-        top_p += "\":</P><P>\n";
+        top_p += "\":</p><p>\n";
         start_loclist (top_p);
       }
       list_location (top_p, si, i);
@@ -842,10 +848,10 @@ Content-type: text/html\n\
     for (i=0; i<si->length(); i++) {
       if ((*si)[i]->name.strcasestr (locq) != -1) {
 	if (count == 0) {
-          top_p += "<P> Regular query found no matches; using more aggressive (substring) query. </P>\n";
-	  top_p += "<P>Locations matching \"";
+          top_p += "<p> Regular query found no matches; using more aggressive (substring) query. </p>\n";
+	  top_p += "<p>Locations matching \"";
 	  top_p += locq;
-	  top_p += "\":</P><P>\n";
+	  top_p += "\":</p><p>\n";
 	  start_loclist (top_p);
 	}
 	list_location (top_p, si, i);
@@ -859,10 +865,10 @@ Content-type: text/html\n\
     if (count)
       end_loclist (top_p);
     else
-      top_p += "<P> No locations matched your query.  However, that might\n\
-just mean that something is spelled strangely in the XTide database.  To\n\
+      top_p += "<p> No locations matched your query.&nbsp; However, that might\n\
+just mean that something is spelled strangely in the XTide database.&nbsp; To\n\
 make sure that you aren't missing a location that is actually in there,\n\
-you should check the indexes linked below.</P>\n";
+you should check the indexes linked below.</p>\n";
   }
   write (s, top_p.aschar(), top_p.length());
   end_page (s);
@@ -895,6 +901,21 @@ log_hits (struct sockaddr *addr) {
   log (msg, LOG_INFO);
 }
 
+static void 
+robots (int s) {
+  Dstr top_p ("\
+HTTP/1.0 200 OK\n\
+MIME-version: 1.0\n\
+Content-type: text/plain\n\
+\n\
+User-agent: *\n\
+Disallow: /\n");
+
+  write (s, top_p.aschar(), top_p.length());
+  close (s);
+  exit (0);
+}
+
 static void
 handle_request (struct sockaddr *addr, int s) {
   char request[bufsize+1];
@@ -927,6 +948,8 @@ handle_request (struct sockaddr *addr, int s) {
 
   if (filename == "/")
     root_page (s);
+  else if (filename == "/robots.txt")
+    robots (s);
   else if (filename == "/index.html")
     index_page (s);
   else if (filename == "/tricks.html")
