@@ -1,5 +1,5 @@
+// $Id: xxXTideRoot.cc,v 1.1 2000/08/30 23:00:16 dave Exp $
 /*  xxXTideRoot  XTide "root" window
-    Last modified 1999-03-15
 
     Copyright (C) 1998  David Flater.
 
@@ -139,6 +139,18 @@ in your date/time formats."); \
   default:
     assert (0);
   }
+  switch (nschoice->choice()) {
+  case 0:
+    newset.ns = "y";
+    break;
+  case 1:
+    newset.ns = "n";
+    break;
+  case 2:
+    break;
+  default:
+    assert (0);
+  }
   switch (tlchoice->choice()) {
   case 0:
     newset.tl = "y";
@@ -429,6 +441,18 @@ xxXTideRoot::xxXTideRoot (int in_argc, char **in_argv) {
     nfchoice = new xxMultiChoice (box,
       "Draw tide graphs as line graphs?", togglechoices, firstchoice);
   }
+  {
+    Dstr t = ud->ns;
+    unsigned firstchoice;
+    if (t.isNull())
+      firstchoice = 2;
+    else if (t == "n")
+      firstchoice = 1;
+    else
+      firstchoice = 0;
+    nschoice = new xxMultiChoice (box,
+      "Suppress sunrise, sunset, moon phases?", togglechoices, firstchoice);
+  }
   {
     Dstr t = ud->tl;
     unsigned firstchoice;
@@ -603,6 +627,7 @@ void xxXTideRoot::global_redraw() {
 
   elchoice->global_redraw();
   nfchoice->global_redraw();
+  nschoice->global_redraw();
   tlchoice->global_redraw();
   zchoice->global_redraw();
   uchoice->global_redraw();
@@ -668,6 +693,7 @@ xxXTideRoot::~xxXTideRoot () {
   delete cwchoice;
   delete elchoice;
   delete nfchoice;
+  delete nschoice;
   delete tlchoice;
   delete zchoice;
   delete uchoice;
